@@ -1,6 +1,17 @@
 import asyncio
 import logging
-from typing import Any, Awaitable, Callable, Dict, List, Optional, Tuple, Union, cast
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Awaitable,
+    Callable,
+    Dict,
+    List,
+    Optional,
+    Tuple,
+    Union,
+    cast,
+)
 
 import attr
 import zeroconf
@@ -31,12 +42,14 @@ from aioesphomeapi.api_pb2 import (  # type: ignore
     ListEntitiesDoneResponse,
     ListEntitiesFanResponse,
     ListEntitiesLightResponse,
+    ListEntitiesNumberResponse,
     ListEntitiesRequest,
     ListEntitiesSensorResponse,
     ListEntitiesServicesResponse,
     ListEntitiesSwitchResponse,
     ListEntitiesTextSensorResponse,
-    LogLevel,
+    NumberCommandRequest,
+    NumberStateResponse,
     SensorStateResponse,
     SubscribeHomeassistantServicesRequest,
     SubscribeHomeAssistantStateResponse,
@@ -74,6 +87,8 @@ from aioesphomeapi.model import (
     LegacyCoverCommand,
     LightInfo,
     LightState,
+    NumberInfo,
+    NumberState,
     SensorInfo,
     SensorState,
     SwitchInfo,
@@ -85,6 +100,9 @@ from aioesphomeapi.model import (
     UserServiceArgType,
 )
 
+if TYPE_CHECKING:
+    from aioesphomeapi.api_pb2 import LogLevel  # type: ignore
+
 _LOGGER = logging.getLogger(__name__)
 
 ExecuteServiceDataType = Dict[
@@ -193,6 +211,7 @@ class APIClient:
             ListEntitiesCoverResponse: CoverInfo,
             ListEntitiesFanResponse: FanInfo,
             ListEntitiesLightResponse: LightInfo,
+            ListEntitiesNumberResponse: NumberInfo,
             ListEntitiesSensorResponse: SensorInfo,
             ListEntitiesSwitchResponse: SwitchInfo,
             ListEntitiesTextSensorResponse: TextSensorInfo,
@@ -252,6 +271,7 @@ class APIClient:
             CoverStateResponse: CoverState,
             FanStateResponse: FanState,
             LightStateResponse: LightState,
+            NumberStateResponse: NumberState,
             SensorStateResponse: SensorState,
             SwitchStateResponse: SwitchState,
             TextSensorStateResponse: TextSensorState,
@@ -289,7 +309,7 @@ class APIClient:
     async def subscribe_logs(
         self,
         on_log: Callable[[SubscribeLogsResponse], None],
-        log_level: Optional[LogLevel] = None,
+        log_level: Optional["LogLevel"] = None,
     ) -> None:
         self._check_authenticated()
 
@@ -517,6 +537,15 @@ class APIClient:
         assert self._connection is not None
         await self._connection.send_message(req)
 
+    async def number_command(self, key: int, state: float) -> None:
+        self._check_authenticated()
+
+        req = NumberCommandRequest()
+        req.key = key
+        req.state = state
+        assert self._connection is not None
+        await self._connection.send_message(req)
+
     async def execute_service(
         self, service: UserService, data: ExecuteServiceDataType
     ) -> None:
