@@ -30,11 +30,14 @@ from aioesphomeapi.api_pb2 import (  # type: ignore
     ListEntitiesDoneResponse,
     ListEntitiesFanResponse,
     ListEntitiesLightResponse,
+    ListEntitiesNumberResponse,
     ListEntitiesRequest,
     ListEntitiesSensorResponse,
     ListEntitiesServicesResponse,
     ListEntitiesSwitchResponse,
     ListEntitiesTextSensorResponse,
+    NumberCommandRequest,
+    NumberStateResponse,
     PingRequest,
     PingResponse,
     SensorStateResponse,
@@ -103,4 +106,7 @@ MESSAGE_TYPE_TO_PROTO = {
     46: ListEntitiesClimateResponse,
     47: ClimateStateResponse,
     48: ClimateCommandRequest,
+    49: ListEntitiesNumberResponse,
+    50: NumberStateResponse,
+    51: NumberCommandRequest,
 }
